#
# spec file for package libsidplayfp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 6
%define stilview_soname 0
Name:           libsidplayfp
Version:        2.1.2
Release:        bp154.1.55
Summary:        A library to play Commodore 64 music
License:        GPL-2.0-or-later
Group:          System/Libraries
URL:            https://sourceforge.net/projects/sidplay-residfp/
Source0:        https://sourceforge.net/projects/sidplay-residfp/files/libsidplayfp/2.1/libsidplayfp-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libftdi1)

%description
A library to play Commodore 64 music based on libsidplay2.

%package -n libsidplayfp%{soname}
Summary:        A library to play Commodore 64 music
Group:          System/Libraries

%description -n libsidplayfp%{soname}
A library to play Commodore 64 music based on libsidplay2.

%package devel
Summary:        Development files for libsidplayfp
Group:          Development/Libraries/C and C++
Requires:       libsidplayfp%{soname} = %{version}

%description devel
This package contains headers and libraries required to build applications that
use libsidplayfp.

%package -n libstilview%{stilview_soname}
Summary:        A library to play Commodore 64 music
Group:          System/Libraries

%description -n libstilview%{stilview_soname}
A library to play Commodore 64 music based on libsidplay2.

%package -n libstilview-devel
Summary:        Development files for libstilview
Group:          Development/Libraries/C and C++
Requires:       libstilview%{stilview_soname} = %{version}

%description -n libstilview-devel
This package contains headers and libraries required to build applications that
use libstilview.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libsidplayfp%{soname} -p /sbin/ldconfig
%postun -n libsidplayfp%{soname} -p /sbin/ldconfig
%post -n libstilview%{stilview_soname} -p /sbin/ldconfig
%postun -n libstilview%{stilview_soname} -p /sbin/ldconfig

%files -n libsidplayfp%{soname}
%license COPYING
%{_libdir}/libsidplayfp.so.%{soname}*

%files -n libstilview%{stilview_soname}
%license COPYING
%{_libdir}/libstilview.so.%{stilview_soname}*

%files devel
%doc AUTHORS NEWS README TODO
%{_libdir}/libsidplayfp.so
%{_includedir}/sidplayfp/
%{_libdir}/pkgconfig/libsidplayfp.pc

%files -n libstilview-devel
%doc AUTHORS NEWS README TODO
%{_libdir}/libstilview.so
%{_includedir}/stilview/
%{_libdir}/pkgconfig/libstilview.pc

%changelog
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.1.2:
  * songlength DB: fix parsing of milliseconds with leading zeroes
  * Fixed building hardsid support
  * reSIDfp: shift register regression fixes
  * Updated RAM init pattern similar to how it's done in VICE
  * Do not use smart pointers in public headers
    (Warning! breaks ABI compatibility)
  * resid/residfp: Use soft instead of hard clipping
    rough implementation of bitfade
  * residfp: better bandpass frequency calculation,
    updated 8580 resistor ratios based on schematics and adjusted
    voltage range, updated TTL values, assume a high impedance
    audio amplifier yielding an 1.6Hz high-pass
- Update to version 2.0.5:
  * Fixed CIA SDR handling, code borrowed from Denise emulator
  * Fixed external filter coefficients calculation in resid/residfp
  * Update osc3 on waveform zero in resid/residfp
  * Further improved CPU/CIA/VICII emulation based on VICE testprogs
  * Fixed an envelope generator regression in resid/residfp
  * Improved noise+pulse interaction in resid/residfp
  * Avoid saturation of residfp 8580 filter
  * Adjusted residfp 6581 filter parameter range
  * Recalculate noise output when actually changed in residfp
  * Fix loading stereo mus tunes
  * Fix residfp envelope
  * Make digiboost work with resid
  * Make MUS loading more robust to malformed files
  * Reworked SidDatabase API
  * Fix hang on exit
  * CIA model is now configurable
  * Added digiboost support
  * Added support for milliseconds in SLDB
  * Improved 8580 filter
  * CIA and SID fixes ported from VICE
  * Added MOS 6573 (PAL-M) emulation
  * Other minor fixes and code cleanup
  * Do not use kernal calls in psid driver
* Fri Jan 13 2017 olaf@aepfle.de
- Update to version 1.8.7
  * Fix out of range tune selection
  * Reenable accidentally broken branch hints in residfp
  * Minor fix in VIC-II code ported from VICE
  * Fix an off-by-one error in mixer code
  * Slightly improve some combined waveforms
  * Fix a regression in VIC-II code
  * Improve combined waveforms emulation
  * Fix a possible crash when locking a sid device fails
  * Fix an overflow in resid/residfp for 8580 output, noticed in /MUSICIANS/L/Linus/64_Forever.sid
  * Use log1p in resid/residfp for improved precision of 6581 filter parameter calculation
  * Fix a warning in PSID model checking
  * Fix running with -b parameter
  * Attenuate second chip output by 3dB in 3SID mode as it is mixed in both channels
  * Fix uninitialized vars
  * Fix a regresion in MUS loader introduced in 1.8.0
  * Fix a regresion in STIL
  * Rework and clean tune loading to be more portable
  * Add support for 3SID files (PSID v4)
  * Check if lightpen is really triggered before changing state
  * Define WIN32_LEAN_AND_MEAN when compiling on MinGW
  * Other minor fixes and improvements
  * Fix interpolation outside bounds in reSIDfp
  * Remove redundant code in PSID loader
  * Fix reported number of channels
  * Install psid driver before placing tune, fixes BASIC tunes and /MUSICIANS/L/Legg_Stephen/Steigar.sid
  * Apply volume to channels, not to chips output
* Thu Feb 12 2015 p.drouand@gmail.com
- Update to version 1.7.0
  * Add an interface to access tune data
  * Remove generated files only for maintainer-clean target (bug #14)
  * Rework Makefile rules for generated files
  * Silence some warnings
  * Other minor changes in reSIDfp
  * Merge minor changes from zxtune fork
* Fri Oct 17 2014 olaf@aepfle.de
- Update to 1.6.0
  * Make PSID loader adhere to spec when handling 2nd SID address
  * Improve PAL/NTSC switch handling
  * Reset rom descriptions if rom is not loaded
  * Fix a memory leak due to deleting auto_ptr to incomplete type (bug #13)
  * Fix Drean TOD frequency
  * Rework lightpen emulation based on VICE's code
  * Internal code refactoring
- Update to 1.5.3
  * Copy poweron pattern in memory only if real c64 compatibility is needed, fixes /MUSICIANS/B/Brennan_Neil/Super_Pac-Man.sid
- Update to 1.5.2
  * Restore original iomap function, fixes /MUSICIANS/C/Cooksey_Mark/Airwolf.sid
- Update to 1.5.1
  * Correctly interpret second sid address from PSID tunes header, fixes /MUSICIANS/T/TSM/Fiki_Fiki_2SID.sid
  * Fix a signedness warning
- Update to 1.5.0
  * Port CIA TOD fixes from VICE
  * Port some VIC-II changes from VICE
  * Check load address only for RSID tunes, fixes Hellbound from Shining 8
  * Minor changes to reSIDfp
  * Other minor fixes and improvements
* Fri Jul 11 2014 reddwarf@opensuse.org
- Update to 1.4.2
  * Fix a typo made during merging in VIC II code
  * Use vector instead of non-standard VLA
- Update to 1.4.1
  * Fix crash when trying to open a directory on *NIX
  * Various VIC II fixes, makes /MUSICIANS/T/The_Power_Terminator/Act_of_Revenge.sid play at the right speed
- Update to 1.4.0
  * Drive the CIA TOD counter using the actual power line frequency
  * Cleanup playing routine
  * Fix residfp's distorted sound on Mahoney's Kapla Caves
  * Rewrite residfp's interpolation routine using Fritsch-Carlson method to preserve monotonicity
  * Reduce size of some residfp's structures
- Update to 1.3.0
  * Port some missing VIC-II changes from jsidplay2
  * Port missing changes from reSID to reSIDfp
  * Fix a bug in psid driver that broke /DEMOS/G-L/Gott_Och_Blandat.sid
  * Fix building with --disable-inline
  * Other minor fixes and improvements
- Update to 1.2.2
  * Extend the waveform TTL to about one second to fix /MUSICIANS/P/PVCF/Thomkat_with_Strange_End.sid
  * Reduce oversized array in reSIDfp
- Update to 1.2.1
  * Fix a bug in VIC-II that broke DEMOS/S-Z/Still_Got_the_Booze_tune_5.sid
  * Fix some wrong values printed by the cpu debugger
- Update to 1.2.0
  * Clean up includes with the help of IWYU (http://code.google.com/p/include-what-you-use/)
  * Improve checks for non-standard functions
  * Enable use of graphviz for doxygen documentation
  * Refactor mixer to be more clean and flexible
  * Improve the clock frequency calculation. Should fix the slightly off PAL-B clock
  * Fix a memory leak introduced in r1015 (bug #11)
  * Some internal refactoring
* Thu Nov 28 2013 reddwarf@opensuse.org
- Update to 1.1.0
* Sat Aug 17 2013 reddwarf@opensuse.org
- Update to 1.0.3
* Sat Jun  1 2013 reddwarf@opensuse.org
- Update to 1.0.2
* Wed Apr 17 2013 reddwarf@opensuse.org
- Update to 1.0.1
* Wed Feb 13 2013 reddwarf@opensuse.org
- Update to 1.0.0
* Sat Sep  1 2012 reddwarf@opensuse.org
- Initial package
